# apex get test

Display test results for a specific asynchronous test run.

## Description for apex get test

Provide a test run ID to display test results for an enqueued or completed asynchronous test run. The test run ID is displayed after running the "sf apex test run" command.

To see code coverage results, use the --code-coverage flag with --result-format. The output displays a high-level summary of the test run and the code coverage values for classes in your org. If you specify human-readable result format, use the --detailed-coverage flag to see detailed coverage results for each test method run.

## Aliases for apex get test

`force:apex:test:report`

## Flags

| Flag Name (Long)      | Flag Name (Short) | Description                                                                                                                                         |
| --------------------- | ----------------- | --------------------------------------------------------------------------------------------------------------------------------------------------- |
| `--api-version`       | N/A               | **Type:** Value<br><br>Override the api version used for api requests made by this command                                                          |
| `--code-coverage`     | `-c`              | **Type:** Boolean<br><br>Retrieve code coverage results.                                                                                            |
| `--concise`           | N/A               | **Type:** Boolean<br><br>Display only failed test results; works with human-readable output only.                                                   |
| `--detailed-coverage` | N/A               | **Type:** Boolean<br><br>Display detailed code coverage per test.                                                                                   |
| `--flags-dir`         | N/A               | **Type:** Value<br><br>Import flag values from a directory.                                                                                         |
| `--json`              | N/A               | **Type:** Boolean<br><br>Format output as json.                                                                                                     |
| `--output-dir`        | `-d`              | **Type:** Value<br><br>Directory in which to store test result files.                                                                               |
| `--result-format`     | `-r`              | **Type:** Value<br>**Valid Values:** `human`, `tap`, `junit`, `json`<br>**Default value:** `human`<br><br>Format of the test results.               |
| `--target-org`        | `-o`              | **Type:** Value<br>**Required**<br><br>Username or alias of the target org. Not required if the `target-org` configuration variable is already set. |
| `--test-run-id`       | `-i`              | **Type:** Value<br>**Required**<br><br>ID of the test run.                                                                                          |

## Examples for apex get test

Display test results for your default org using a test run ID:

```shell
sf apex get test --test-run-id <test run id>
```

Similar to previous example, but output the result in JUnit format:

```shell
sf apex get test --test-run-id <test run id> --result-format junit
```

Also retrieve code coverage results and output in JSON format:

```shell
sf apex get test --test-run-id <test run id> --code-coverage --json
```

Specify a directory in which to save the test results from the org with the specified username (rather than your default org):

```shell
sf apex get test --test-run-id <test run id> --code-coverage --output-dir <path to outputdir> --target-org me@myorg'
```
